pub struct CountedHeader {
pub header: Arc<Header>,
}Expand description
A header with a count of the number of transactions in its block. This structure is used in the Bitcoin network protocol.
The transaction count field is always zero, so we don’t store it in the struct.
Fields
header: Arc<Header>The header for a block